@@ -3,12 +3,17 @@ from p.__init__ import *
 from p.y import *
 from p.yh import *
 from p.yz import *
+#from music.music import *
+#from os import system as s
+#s('cd music')
+#s('python -m music.py')
+
 def main():
     A()
     print('\033[1;1m 由于更换颜色太费时费力,所以只加入了部分颜色,请谅解')
     print('\033[7;36m本次开始使用时间:\033[0m','\033[7;32m',start,'\nWelcome Users!','\033[0m')
     while True:
-        print('\033[1;1m')
+        print('\033[1;1m','【三圆整合】')
         print('=====切换/选择模式，请选择=====\n模式1.计算关于圆的计算(输入1执行)\n模式2.计算关于圆柱的计算(输入2执行)\n模式3.计算关于圆环的计算(输入3执行)\n输入其他数字退出\n')
         yyy=input('请选择模式(输入数字):')
         try:
@@ -26,5 +31,5 @@ def main():
         else:
             end=sj.now()-start
             print('即将\033[10;31m退出\033[0m,','本次使用时间:',end,'\n程序将在5秒后关闭,谢谢使用')
-            dd(5)
+            exitings(5)
             tc()
