@@ -1,19 +1,24 @@
 __Author__='神秘的·'
 __Project__='三个圆整合'
 __version__='0.4'#2.6.5.2
+from time import sleep as dd
 def A():#作者&运算符相关   
     print('\033[1;5;44m作者:' ,__Author__,'\033[0m')  
     print('\033[1;5;44m版本:',__version__ ,'\033[0m')
     print('\033[1;5;44mname:',__Project__,'\033[0m')
+    dd(0.2)
     print('\033[100;100;100m若出现bug你可以通过 \033[1mhttps://pypi.org/project/ycc/\033[0m\033[100;100;100m找到我的联系方式')
+    dd(0.1)
     print('\033[1;6;45m编程语言:python\n编辑器(IDLE):pydroid\033[0m')
     print('\n\033[7;33m警告:','\033[0m','\033[9;7;31m严禁\033[0m','用于',
     '\033[7;7;35m非法用途\033[0m','若','\033[7;7;31m触犯','\033[7;7;31m法律\033[0m ',
     '\033[7;44m作者\033[0m','\033[7;7;31m概不负责\033[0m','\033[4;36m最终解释权\033[0m','\033[7;44m归作者\033[0m','\033[1;44m所有。\033[0m')
+    dd(0.2)
     print('\033[7;5;31m仅供娱乐!!!!!!\033[0m')
     print('\033[1;44m支持\033[0m','输入运算符(选项除外)，但是python中的运算符与手写有一些','\033[2;44m区别\033[0m\n','\033[4;32m×要写成* ÷要写成/ ＋要写成+  －要写成-\033[0m\n','(英文字符;加减号是有区别的)**')
+    dd(0.05)
 pai2='π' #下面要用到，提前放上来 
-def dw():
+def dw():#单位
     print('请自行换算单位并保持单位一致')
 from math import pi as pai1
 def aboutpi():
@@ -27,4 +32,5 @@ def aboutpi():
     **→_→如果选择4，请先输入半径后输入你定义π的数值
     其他选项:
     5.输入5,切换模式
-    6.输入不是1~5中的数,直接退出''')
\ No newline at end of file
+    6.输入不是1~5中的数,直接退出''')
+#A()#test
\ No newline at end of file
